@@ -17,6 +17,7 @@ from euphorie.client.browser.country import SessionsView
 from euphorie.client.model import get_current_account
 from euphorie.content.survey import ISurvey
 from plone import api
+from plone.memoize.view import memoize
 from plone.session.plugins.session import cookie_expiration_date
 from plonetheme.nuplone.tiles.analytics import trigger_extra_pageview
 from Products.CMFCore.utils import getToolByName
@@ -51,6 +52,11 @@ class Login(BrowserView):
     error = False
     errors = {}
 
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
     def setLanguage(self, came_from):
         qs = urlparse(came_from)[4]
         params = parse_qs(qs)
@@ -115,6 +121,8 @@ class Login(BrowserView):
             )
 
     def _tryRegistration(self):
+        if not self.webhelpers.allow_self_registration:
+            raise Unauthorized("No self registration allowed.")
         form = self.request.form
         loginname = form.get("email")
         if not loginname:
@@ -208,11 +216,10 @@ class Login(BrowserView):
             if isinstance(came_from, list):
                 # If came_from is both in the querystring and the form data
                 came_from = came_from[0]
-            self.setLanguage(came_from)
         else:
             # Set to country url
-            webhelpers = api.content.get_view("webhelpers", context, self.request)
-            came_from = webhelpers.country_url
+            came_from = self.webhelpers.country_url
+        self.setLanguage(came_from)
 
         account = get_current_account()
         self.allow_guest_accounts = api.portal.get_registry_record(
