@@ -226,7 +226,7 @@ class SurveyImporter(object):
         )
         EnsureInterface(risk)
         risk.type = node.get("type")
-        risk.description = six.text_type(node.description)
+        risk.description = six.text_type(getattr(node, "description", ""))
         risk.problem_description = el_unicode(node, "problem-description")
         risk.legal_reference = el_unicode(node, "legal-reference")
         risk.show_notapplicable = el_bool(node, "show-not-applicable")
@@ -384,11 +384,15 @@ class SurveyImporter(object):
         enablde DOM.
         """
         if isinstance(input, six.string_types + (bytes,)):
-            parser = lxml.etree.XMLParser(huge_tree=True)
-            sector_tree = lxml.objectify.parse(
-                BytesIO(safe_bytes(input)), parser=parser
-            )
-            sector = lxml.objectify.fromstring(lxml.etree.tostring(sector_tree))
+            try:
+                sector = lxml.objectify.fromstring(safe_bytes(input))
+            except Exception:
+                # It might be that the file is huge, let's try a different approach
+                parser = lxml.etree.XMLParser(huge_tree=True)
+                sector_tree = lxml.objectify.parse(
+                    BytesIO(safe_bytes(input)), parser=parser
+                )
+                sector = lxml.objectify.fromstring(lxml.etree.tostring(sector_tree))
         else:
             sector = input
 
