@@ -9,9 +9,10 @@ using a fully initialized environment using ``bin/instance``::
 from euphorie.client import model
 from z3c.saconfig import Session
 
+
 def main(app, args):
     model.metadata.create_all(Session.bind, checkfirst=True)
 
-if __name__=="__main__":
-    main(app, ())
 
+if __name__ == "__main__":
+    main(app, ())  # noqa: F821
